@@ -15,11 +15,11 @@
 #define LLVM_CONFIG_H
 
 /* Define if LLVM_ENABLE_DUMP is enabled */
-#define LLVM_ENABLE_DUMP
+/* #undef LLVM_ENABLE_DUMP */
 
 /* Target triple LLVM will generate code for by default */
 /* Doesn't use `cmakedefine` because it is allowed to be empty. */
-#define LLVM_DEFAULT_TARGET_TRIPLE "x86_64-pc-windows-cygnus"
+#define LLVM_DEFAULT_TARGET_TRIPLE "x86_64-pc-linux-gnu"
 
 /* Define if threads enabled */
 #define LLVM_ENABLE_THREADS 1
@@ -28,7 +28,7 @@
 #define LLVM_HAS_ATOMICS 1
 
 /* Host triple LLVM will be executed on */
-#define LLVM_HOST_TRIPLE "x86_64-pc-windows-cygnus"
+#define LLVM_HOST_TRIPLE "x86_64-pc-linux-gnu"
 
 /* LLVM architecture name for the native architecture, if available */
 #define LLVM_NATIVE_ARCH X86
@@ -58,7 +58,7 @@
 #define LLVM_HAS_AARCH64_TARGET 1
 
 /* Define if the AMDGPU target is built in */
-#define LLVM_HAS_AMDGPU_TARGET 0
+#define LLVM_HAS_AMDGPU_TARGET 1
 
 /* Define if the ARC target is built in */
 #define LLVM_HAS_ARC_TARGET 0
@@ -67,10 +67,10 @@
 #define LLVM_HAS_ARM_TARGET 1
 
 /* Define if the AVR target is built in */
-#define LLVM_HAS_AVR_TARGET 0
+#define LLVM_HAS_AVR_TARGET 1
 
 /* Define if the BPF target is built in */
-#define LLVM_HAS_BPF_TARGET 0
+#define LLVM_HAS_BPF_TARGET 1
 
 /* Define if the CSKY target is built in */
 #define LLVM_HAS_CSKY_TARGET 0
@@ -79,52 +79,52 @@
 #define LLVM_HAS_DIRECTX_TARGET 0
 
 /* Define if the Hexagon target is built in */
-#define LLVM_HAS_HEXAGON_TARGET 0
+#define LLVM_HAS_HEXAGON_TARGET 1
 
 /* Define if the Lanai target is built in */
-#define LLVM_HAS_LANAI_TARGET 0
+#define LLVM_HAS_LANAI_TARGET 1
 
 /* Define if the LoongArch target is built in */
-#define LLVM_HAS_LOONGARCH_TARGET 0
+#define LLVM_HAS_LOONGARCH_TARGET 1
 
 /* Define if the M68k target is built in */
 #define LLVM_HAS_M68K_TARGET 0
 
 /* Define if the Mips target is built in */
-#define LLVM_HAS_MIPS_TARGET 0
+#define LLVM_HAS_MIPS_TARGET 1
 
 /* Define if the MSP430 target is built in */
-#define LLVM_HAS_MSP430_TARGET 0
+#define LLVM_HAS_MSP430_TARGET 1
 
 /* Define if the NVPTX target is built in */
-#define LLVM_HAS_NVPTX_TARGET 0
+#define LLVM_HAS_NVPTX_TARGET 1
 
 /* Define if the PowerPC target is built in */
-#define LLVM_HAS_POWERPC_TARGET 0
+#define LLVM_HAS_POWERPC_TARGET 1
 
 /* Define if the RISCV target is built in */
-#define LLVM_HAS_RISCV_TARGET 0
+#define LLVM_HAS_RISCV_TARGET 1
 
 /* Define if the Sparc target is built in */
-#define LLVM_HAS_SPARC_TARGET 0
+#define LLVM_HAS_SPARC_TARGET 1
 
 /* Define if the SPIRV target is built in */
-#define LLVM_HAS_SPIRV_TARGET 0
+#define LLVM_HAS_SPIRV_TARGET 1
 
 /* Define if the SystemZ target is built in */
-#define LLVM_HAS_SYSTEMZ_TARGET 0
+#define LLVM_HAS_SYSTEMZ_TARGET 1
 
 /* Define if the VE target is built in */
-#define LLVM_HAS_VE_TARGET 0
+#define LLVM_HAS_VE_TARGET 1
 
 /* Define if the WebAssembly target is built in */
-#define LLVM_HAS_WEBASSEMBLY_TARGET 0
+#define LLVM_HAS_WEBASSEMBLY_TARGET 1
 
 /* Define if the X86 target is built in */
 #define LLVM_HAS_X86_TARGET 1
 
 /* Define if the XCore target is built in */
-#define LLVM_HAS_XCORE_TARGET 0
+#define LLVM_HAS_XCORE_TARGET 1
 
 /* Define if the Xtensa target is built in */
 #define LLVM_HAS_XTENSA_TARGET 0
@@ -139,7 +139,7 @@
 #define LLVM_USE_OPROFILE 0
 
 /* Define if we have the perf JIT-support library */
-#define LLVM_USE_PERF 0
+#define LLVM_USE_PERF 1
 
 /* Major version of the LLVM API */
 #define LLVM_VERSION_MAJOR 20
@@ -162,7 +162,7 @@
 /* #undef LLVM_WITH_Z3 */
 
 /* Define if we have curl and want to use it */
-/* #undef LLVM_ENABLE_CURL */
+#define LLVM_ENABLE_CURL 1
 
 /* Define if we have cpp-httplib and want to use it */
 /* #undef LLVM_ENABLE_HTTPLIB */
